// @author      Kelvin Hui
// @see       	it-blogs.com
// @since     	01-Mar-2016

//Declare required library
var express 			= require('express');
var fs 					= require('fs');
var morgan 				= require('morgan');
var FileStreamRotator 	= require('file-stream-rotator');

var app = express();
var logFolder = __dirname + '/log';

fs.existsSync(logFolder) || fs.mkdirSync(logFolder);

//Logger details
var logFileStream = FileStreamRotator.getStream({
  date_format: 	'YYYY-MM-DD',
  filename: 	logFolder + '/demo4_%DATE%.log',
  frequency: 	'daily',
  verbose: 		false
});

//Setup app variables
app.set('port', 3000);

app.use(morgan('combined', {stream: logFileStream}));

//Setup the index page
app.get('/', function(req, res) {
	res.send( [{title: 'Example 4: Audio and Video Streaming App', message: 'This example will show you how to stream audio and video using Node.js , you will find that it is so simple to do so with just a few line of codes.'}] );
});

//Setup audio request URL
app.get('/audio', function(req, res) {
	//Define the video file
	var path = __dirname + '/files/' + 'sample1.mp3';
	var stat = fs.statSync(path);
	var total = stat.size;
	
	console.log('path='+path);
	console.log('stat='+stat);	
	console.log('total='+total);

    res.writeHead(200, { 
		'Content-Length': total, 
		'Content-Type': 'audio/mpeg' 
	});
    fs.createReadStream(path).pipe(res);
});

//Setup video request URL
app.get('/video', function(req, res) {
	//Define the video file
	var path = __dirname + '/files/' + 'sample2.mp4';
	var stat = fs.statSync(path);
	var total = stat.size;
	
	console.log('path='+path);
	console.log('stat='+stat);	
	console.log('total='+total);

    res.writeHead(200, { 
		'Content-Length': total, 
		'Content-Type': 'video/mp4' 
	});
    fs.createReadStream(path).pipe(res);
});

//Setup Listener with Port app.get('port')
app.listen(app.get('port'), function () {
	console.log('Demo 4 listening on port ' + app.get('port'));
});